@@ -28,14 +28,14 @@ dUtilityWORK <- function (x, xm, method = "IL1")
   if (method == "IL1") {
     a <- x
     for (i in 1:dim(x)[2]) {
-      a[, i] <- abs((x[, i] - xm[, i])/sd(x[, i]) * sqrt(2))
+      a[, i] <- abs((x[, i] - xm[, i])/sd(x[, i], na.rm=TRUE) * sqrt(2))
     }
-    infLoss1 <- 1/(dim(x)[2]*dim(x)[1]) * sum(a)
+    infLoss1 <- 1/(dim(x)[2]*dim(x)[1]) * sum(a, na.rm=TRUE)
     return(infLoss1)
   }
   if (method == "eigen") {
-    e1 <- eigen(cov(scale(x)))$values
-    e2 <- eigen(cov(scale(xm)))$values
+    e1 <- eigen(var(scale(x), na.rm=TRUE,use="pairwise.complete.obs"))$values
+    e2 <- eigen(var(scale(xm),na.rm=TRUE,use="pairwise.complete.obs"))$values
     d <- sum(abs(e1 - e2)/e1)
     return(d)
   }
